# Generated by Django 4.2 on 2023-04-29 15:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='domains',
            name='Description',
            field=models.CharField(blank=True, max_length=15),
        ),
    ]
