# Generated by Django 4.0.6 on 2022-08-10 10:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userinfo',
            options={'verbose_name': 'User Advance Information', 'verbose_name_plural': 'Profile Details'},
        ),
    ]
